@@ -7,3 +7,6 @@ class Basket(object):
     @property
     def price(self):
         return self.price_currency + " " + str(self.price_amount / 100)
+
+    def __str__(self):
+        return f"{self.amount} {self.price_currency} {self.price_amount} {self.price}"
